@@ -1,8 +1,21 @@
+/*
+ * Copyright (C) 2005 Joe Walnes.
+ * Copyright (C) 2006, 2007 XStream Committers.
+ * All rights reserved.
+ *
+ * The software in this package is published under the terms of the BSD
+ * style license a copy of which has been included with this distribution in
+ * the LICENSE.txt file.
+ * 
+ * Created on 30. April 2005 by Joe Walnes
+ */
 package com.thoughtworks.acceptance;
 
 import javax.swing.DefaultListModel;
 import javax.swing.JList;
 import javax.swing.JTable;
+import javax.swing.LookAndFeel;
+import javax.swing.plaf.metal.MetalLookAndFeel;
 
 public class SwingTest extends AbstractAcceptanceTest {
 
@@ -34,4 +47,9 @@ public class SwingTest extends AbstractAcceptanceTest {
         list.setModel(deserialized);
     }
     
+    public void testMetalLookAndFeel() {
+        LookAndFeel plaf = new MetalLookAndFeel();
+        String originalXml = xstream.toXML(plaf);
+        assertBothWays(plaf, originalXml);
+    }
 }
